@@ -3,7 +3,7 @@ use ocy_core::matcher::Matcher;
 
 macro_rules! matcher {
     ($name: expr, $to_match: expr, $to_remove: expr) => {
-        Matcher::new(
+        Matcher::with_remove_strategy(
             $name.into(),
             Pattern::new($to_match).unwrap(),
             Pattern::new($to_remove).unwrap(),
@@ -11,6 +11,16 @@ macro_rules! matcher {
     };
 }
 
+macro_rules! matcher_cmd {
+    ($name: expr, $to_match: expr, $cmd: expr) => {
+        Matcher::with_command_strategy(
+            $name.into(),
+            Pattern::new($to_match).unwrap(),
+            $cmd.to_string(),
+        )
+    };
+}
+
 pub fn standard_matchers() -> Vec<Matcher> {
     vec![
         matcher!("Cargo", "Cargo.toml", "target"),
@@ -21,5 +31,6 @@ pub fn standard_matchers() -> Vec<Matcher> {
         matcher!("XCode", "*", "DerivedData"),
         matcher!("SBT", "build.sbt", "target"),
         matcher!("SBT", "plugins.sbt", "target"),
+        matcher_cmd!("Make", "Makefile", "make clean"),
     ]
 }
